<?php
/**
 * Include the TGM_Plugin_Activation class.
 */
require_once ARIMA_THEME_DIR . '/framework/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'arima_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function arima_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		array(
			'name'     				=> esc_html__('Visual Composer', 'arima'),
			'slug'     				=> 'js_composer',
			'source'   				=> ARIMA_THEME_DIR . '/framework/plugins/js_composer.zip',
			'version' 				=> '6.0.5',
			'required' 				=> true,
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),

		array(
			'name'     				=> esc_html__('Ultimate Addons for Visual Composer', 'arima'),
			'slug'     				=> 'Ultimate_VC_Addons',
			'source'   				=> ARIMA_THEME_DIR . '/framework/plugins/Ultimate_VC_Addons.zip',
			'version' 				=> '3.19.0',
			'required' 				=> false,
		),

		array(
			'name'     				=> esc_html__('Layer Slider', 'arima'),
			'slug'     				=> 'LayerSlider',
			'source'   				=> ARIMA_THEME_DIR . '/framework/plugins/LayerSlider.zip',
			'version' 				=> '6.9.2',
		),

		array(
			'name'     				=> esc_html__('Revolution Slider', 'arima'),
			'slug'     				=> 'revslider',
			'source'   				=> ARIMA_THEME_DIR . '/framework/plugins/revslider.zip',
			'version' 				=> '6.1.1',
		),

		array(
			'name'     				=> esc_html__('DesignThemes Core Features Plugin', 'arima'),
			'slug'     				=> 'designthemes-core-features',
			'source'   				=> ARIMA_THEME_DIR . '/framework/plugins/designthemes-core-features.zip',
			'required' 				=> true,
			'version' 				=> '1.0',
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),

		array(
			'name'     				=> esc_html__('DesignThemes Portfolio Addon', 'arima'),
			'slug'     				=> 'designthemes-portfolio-addon',
			'source'   				=> ARIMA_THEME_DIR . '/framework/plugins/designthemes-portfolio-addon.zip',
			'required' 				=> false,
			'version' 				=> '1.0',
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),

		array(
			'name' 					=> esc_html__('Contact Form 7', 'arima'),
			'slug' 					=> 'contact-form-7',
			'required' 				=> false,
		),

		array(
			'name' 					=> esc_html__('WooCommerce - excelling eCommerce', 'arima'),
			'slug' 					=> 'woocommerce',
			'required' 				=> false,
		),

		array(
			'name' 					=> esc_html__('YITH WooCommerce Wishlist', 'arima'),
			'slug' 					=> 'yith-woocommerce-wishlist',
			'required' 				=> false,
		),

		array(
			'name' 					=> esc_html__('YITH WooCommerce Quick View', 'arima'),
			'slug' 					=> 'yith-woocommerce-quick-view',
			'required' 				=> false,
		),

		array(
			'name' 					=> esc_html__('YITH WooCommerce Compare', 'arima'),
			'slug' 					=> 'yith-woocommerce-compare',
			'required' 				=> false,
		),

		array(
			'name'					=> esc_html__('WP Envato Market', 'arima'),
			'slug'					=> 'wp-envato-market',
			'source'				=> ARIMA_THEME_DIR . '/framework/plugins/wp-envato-market.zip',
		),

		array(
			'name'     				=> esc_html__('Unyson', 'arima'),
			'slug'     				=> 'unyson',
			'required' 				=> true,
		),

		array(
			'name'     				=> esc_html__('Kirki Toolkit', 'arima'),
			'slug'     				=> 'kirki',
			'required' 				=> true,
		)
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'arima',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}?>